@@ -1,5 +1,5 @@
 C Output from Public domain Ratfor, version 1.0
-      subroutine dldins(a,b,slope,rwu,ai,bi,rw,intfnd,bpt)
+      subroutine dldins(a,b,slope,rwu,ai,bi,rw,intfnd,bpt,nedge)
       implicit double precision(a-h,o-z)
       dimension rw(4)
       logical intfnd, bpt, rwu
@@ -13,12 +13,14 @@ C Output from Public domain Ratfor, version 1.0
       ai = a
       bi = b
       bpt = .false.
+      nedge = 0
       return
       endif
       if(.not.rwu)then
       if(b .lt. ymin)then
       ai = a
       bi = ymin
+      nedge = 1
       if(xmin.le.ai.and.ai.le.xmax)then
       return
       endif
@@ -26,6 +28,7 @@ C Output from Public domain Ratfor, version 1.0
       if(b .gt. ymax)then
       ai = a
       bi = ymax
+      nedge = 3
       if(xmin.le.ai.and.ai.le.xmax)then
       return
       endif
@@ -36,6 +39,7 @@ C Output from Public domain Ratfor, version 1.0
       if(a.lt.xmin)then
       ai = xmin
       bi = b + slope*(ai-a)
+      nedge = 2
       if(ymin.le.bi.and.bi.le.ymax)then
       return
       endif
@@ -43,6 +47,7 @@ C Output from Public domain Ratfor, version 1.0
       if(b.lt.ymin)then
       bi = ymin
       ai = a + (bi-b)/slope
+      nedge = 1
       if(xmin.le.ai.and.ai.le.xmax)then
       return
       endif
@@ -50,6 +55,7 @@ C Output from Public domain Ratfor, version 1.0
       if(a.gt.xmax)then
       ai = xmax
       bi = b + slope*(ai-a)
+      nedge = 4
       if(ymin.le.bi.and.bi.le.ymax)then
       return
       endif
@@ -57,6 +63,7 @@ C Output from Public domain Ratfor, version 1.0
       if(b.gt.ymax)then
       bi = ymax
       ai = a + (bi-b)/slope
+      nedge = 3
       if(xmin.le.ai.and.ai.le.xmax)then
       return
       endif
